﻿(function() {
    /**
     * Implementation class for an Accordion View Display Template.
     */
    $.accordionViewer = {
        /**
         * Get the html for the view header.
         * @param {object} the rendering context.
         * @return {string} the HTML text.
         */
        getHeader: function(ctx) {
            var result = $("<p/>"); // placeholder, will return inner html

            // add the expand link
            result.append($("<a/>", {
                "class": "expand",
                "href": "javascript:void(0)",
                "style": "margin-right: 10px; text-decoration: underline"
            }).text("Expand"));

            // add the collapse link
            result.append($("<a/>", {
                "class": "collapse",
                "href": "javascript:void(0)",
                "style": "text-decoration: underline"
            }).text("Collapse"));

            // return the HTML to be rendered
            return result.html();
        },

        /**
         * Get the html for a single item in the view.
         * @param {object} the rendering context.
         * @return {string} the HTML text.
         */
        getItem: function(ctx) {
            var result = $("<p/>"); // placeholder, will return inner html
            
            // add an outer div for the accordion
            var div = $("<div/>", {
                "class": "accordion",
                "style": "width: 800px"
            });
            
            // add a header for the accordion
            div.append($("<h3/>", {
                "class": "accordion-part",
                "style": "font-weight: bold;"
            }).text(ctx.CurrentItem.Title));
            
            // add the body of the accorion
            div.append($("<div/>", {
                "class": "accordion-part"
            }).html(ctx.CurrentItem.Body));
            result.append(div);

            // return the HTML to be rendered (i.e. the accordion)
            return result.html();
        },

        /**
         * Invoke jQuery-UI's accorion on each item, and wire up the expand/collapse all link events.
         * @param {object} the rendering context.         
         */
        postRender: function(ctx) {
            // invoke jQuery-UI's accorion on each item
            $(".accordion").accordion({
                heightStyle: "content",
                collapsible: true,
                active: false // change to true to start all accordions expanded
            });
            //$(".accordion").first().accordion({ active: 0 }); // uncomment to start first accordion expanded

            // add a click handler to the expand link
            $(".expand").click(function() {
                // expand each item
                $(".accordion").accordion({
                    active: 0
                });
            });

            // add a click handler to the collapse link
            $(".collapse").click(function() {
                // collapse each item
                $(".accordion").accordion({
                    active: false
                });
            });
        }
    };

    // our overrides instance
    var overrides = {
        Templates: {
            Header: $.accordionViewer.getHeader,
            Item: $.accordionViewer.getItem,
            Footer: " "
        },
        OnPostRender: $.accordionViewer.postRender
    };

    if (typeof _spPageContextInfo != 'undefined' && _spPageContextInfo != null) {
        // MDS is enabled
        var url = (_spPageContextInfo.siteServerRelativeUrl === '/' ? "" : _spPageContextInfo.siteServerRelativeUrl) +
            '/_catalogs/masterpage/Display Templates/List Views/AccordionViewCSR.js';

        // register a callback to register the templates on partial page loads
        RegisterModuleInit(url, function() {
            SPClientTemplates.TemplateManager.RegisterTemplateOverrides(overrides);
        });
    }

    // register for full page loads (F5/refresh/Or Non-MDS)
    SPClientTemplates.TemplateManager.RegisterTemplateOverrides(overrides);
})(jQuery);
